@@ -1,14 +1,14 @@
 ;;; org-daily-reflection.el --- Concurrent display of org(-roam) dailies  -*- lexical-binding: t; -*-
 
-;; Org Daily Reflection - Compare `N' org(-roam) dailies at `M' intervals
+;; Org Daily Reflection - Compare \='N\=' org(-roam) dailies at \='M\=' intervals
 
 ;; Copyright (C) 2024–2025 Benjamin Slade
 
 ;; Author: Benjamin Slade <slade@lambda-y.net>
 ;; Maintainer: Benjamin Slade <slade@lambda-y.net>
 ;; URL: https://github.com/emacsomancer/org-daily-reflection
-;; Package-Version: 20251120.7
-;; Package-Revision: a6a051b931e1
+;; Package-Version: 20260102.35
+;; Package-Revision: 4f7a2a3b068d
 ;; Package-Requires: ((emacs "26.1") (org "9.4") (compat "30.0.0.0"))
 ;; Created: 2024-07-27
 ;; Keywords: convenience, frames, terminals, tools, window-system
@@ -128,7 +128,7 @@ than 1-year).  If \='nil, then just show 365 days before."
     (expand-file-name org-roam-dailies-directory org-roam-directory))
   "Path to daily-notes."
   :group 'org-daily-reflection
-  :type 'string)
+  :type 'directory)
 
 (defcustom org-daily-reflection-capture-keys nil
   "Template to use for opening dailies.
@@ -199,8 +199,8 @@ E.g., for `delete-other-windows'."
 
 ;;;###autoload
 (defun org-daily-reflection (&optional m n)
-  "Show `N' number of `M' time spans of dailies from the current org daily.
-Choices for `N' are integers and choices for `M' are \='day,
+  "Show \='N\=' number of \='M\=' time spans of dailies from the current org daily.
+Choices for \='N\=' are integers and choices for \='M\=' are \='day,
 \='week, \='fortnight, \='month, \='year, \='decade, and \='century."
   (interactive)
 
@@ -211,12 +211,10 @@ before running.  \(It seems you likely don't have
 `org-roam-dailies-directory' set.\)"))
   
   ;; org-daily-reflect directory/file check
-  (unless (or
-           (org-daily-reflection--daily-note-p)
-           org-daily-reflection-disable-org-roam-daily-check)
+  (unless (org-daily-reflection--daily-note-p)
     (if (y-or-n-p "Not currently in a daily-note. Would you like to jump to today's daily and continue?")
         (org-daily-reflection-jump-to-today)
-      (user-error "Not jumping to a daily. Cannot continue. Please retry when you have a daily open in buffer.")))
+      (user-error "Not jumping to a daily. Cannot continue. Please retry when you have a daily open in buffer")))
   
   ;; ask user for `m' and `n' if called interactively
   (let* ((m (or m
@@ -344,20 +342,23 @@ for more information."))))
 Return \='t if `current-buffer' is an `org-mode' file in
 `org-daily-reflection-dailies-directory' (which is set by default to
 `org-roam-dailies-directory' if available), \='nil otherwise."
-  (when-let* ((a (expand-file-name
-                  (buffer-file-name (current-buffer))))
-                 ;; (buffer-file-name (buffer-base-buffer))))
-             (b (expand-file-name
-                 org-daily-reflection-dailies-directory)))
-    (setq a (expand-file-name a))
-    (if (and (derived-mode-p 'org-mode)
-             (unless (and a b (equal (file-truename a) (file-truename b)))
-               (string-prefix-p
-                (replace-regexp-in-string "^\\([A-Za-z]\\):" 'downcase
-                                          (expand-file-name b) t t)
-                (replace-regexp-in-string "^\\([A-Za-z]\\):" 'downcase
-                                          (expand-file-name a) t t))))
-        t nil)))
+  (if (eq (buffer-file-name (buffer-base-buffer)) nil)
+      nil
+    (if org-daily-reflection-disable-org-roam-daily-check
+        t
+      (when-let* ((a (expand-file-name
+                      (buffer-file-name (buffer-base-buffer))))
+                  (b (expand-file-name
+                      org-daily-reflection-dailies-directory)))
+        (setq a (expand-file-name a))
+        (if (and (derived-mode-p 'org-mode)
+                 (unless (and a b (equal (file-truename a) (file-truename b)))
+                   (string-prefix-p
+                    (replace-regexp-in-string "^\\([A-Za-z]\\):" 'downcase
+                                              (expand-file-name b) t t)
+                    (replace-regexp-in-string "^\\([A-Za-z]\\):" 'downcase
+                                              (expand-file-name a) t t))))
+            t nil)))))
 
 (defun org-daily-reflection--determine-splits (no-of-splits)
   "Determine how many window splits should be made.
@@ -418,8 +419,8 @@ its path if it does."
 
 (defun org-daily-reflection--determine-prev-journal-entry (org-curr-date offset unit)
   "Determine the correct previous daily note date.
-Find the date for the daily journal that would `OFFSET' number of `UNIT'
-before `ORG-CURR-DATE'."
+Find the date for the daily journal that would \='OFFSET\=' number of \='UNIT\='
+before \='ORG-CURR-DATE\='."
   (let* ((ocd-date (decode-time (org-time-string-to-time org-curr-date)))
          (ocd-year (nth 5 ocd-date))
          (ocd-month (nth 4 ocd-date))
@@ -568,21 +569,25 @@ non-nil.
  Can also be used interactively."
   (interactive)
   (while-let ((buf (pop org-daily-reflection--list-of-newly-opened-entries)))
-    (and (buffer-live-p buf)
-         (not (buffer-modified-p buf))
-         (kill-buffer buf))))
+    (and
+     (bufferp buf)
+     (buffer-live-p buf)
+     (not (buffer-modified-p buf))
+     (kill-buffer buf)))
+  (if (or (get-register 'org-daily-reflect--old)
+            (get-register 'org-daily-reflect--old-jumped))
+        (org-daily-reflection-layout-toggle)))
 
 ;;;###autoload
 (defun org-daily-reflection-restore-prior-windows ()
   "Restore the pre-reflection window configuration."
   (interactive)
+  (if (get-register 'org-daily-reflect--old-jumped)
+      (jump-to-register 'org-daily-reflect--old-jumped)
+    (when (get-register 'org-daily-reflect--old)
+      (jump-to-register 'org-daily-reflect--old)))
   (when org-daily-reflection-close-unmodified-newly-opened-buffers
-    (org-daily-reflection-close-reflection-newly-opened))
-  ;; (when (get-register 'org-daily-reflect--old-jumped)
-    ;; (set-register 'org-daily-reflect--old 'org-daily-reflect--old-jumped)
-    ;; (set-register 'org-daily-reflect--old-jumped nil)
-    ;; )
-  (jump-to-register 'org-daily-reflect--old))
+    (org-daily-reflection-close-reflection-newly-opened)))
 
 ;;;###autoload
 (defun org-daily-reflection-layout-toggle ()
@@ -602,14 +607,14 @@ window layout."
           (set-register 'org-daily-reflect--old nil)
           (set-register 'org-daily-reflect--old-jumped nil))
       (if (get-register 'org-daily-reflect--mirrors)
-          (progn            
+          (progn
             (window-configuration-to-register
              'org-daily-reflect--old)
             (jump-to-register 'org-daily-reflect--mirrors)
             (set-register 'org-daily-reflect--mirrors nil))
         (user-error "Something went wrong"))))
 
-(defalias 'org-daily-reflection-exit-or-enter-reflecting 'org-daily-reflection-layout-toggle)
+(defalias 'org-daily-reflection-exit-or-enter-reflecting #'org-daily-reflection-layout-toggle)
 
 ;;; various predefined reflection commands
 
